==> haskell-hspec-meta-2.6.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-meta
version: 2.6.0
id: hspec-meta-2.6.0-A4bbz1LO8vMLr2DjySp2jc
key: hspec-meta-2.6.0-A4bbz1LO8vMLr2DjySp2jc
license: MIT
copyright: (c) 2011-2018 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.
category: Testing
abi: 9d896411d87ea8d48fb488994622d804
exposed: True
exposed-modules:
    Test.Hspec.Meta
hidden-modules: Test.Hspec Test.Hspec.Discover
                Test.Hspec.Formatters Test.Hspec.QuickCheck Test.Hspec.Runner
                Test.Hspec.Core.Clock Test.Hspec.Core.Compat Test.Hspec.Core.Config
                Test.Hspec.Core.Config.Options Test.Hspec.Core.Config.Util
                Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
                Test.Hspec.Core.FailureReport Test.Hspec.Core.Format
                Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
                Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.Hooks
                Test.Hspec.Core.QuickCheck Test.Hspec.Core.QuickCheckUtil
                Test.Hspec.Core.Runner Test.Hspec.Core.Runner.Eval
                Test.Hspec.Core.Spec Test.Hspec.Core.Spec.Monad
                Test.Hspec.Core.Timer Test.Hspec.Core.Tree Test.Hspec.Core.Util
                Control.Concurrent.Async Data.Algorithm.Diff Paths_hspec_meta
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-meta-2.6.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-meta-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-meta-2.6.0
hs-libraries: HShspec-meta-2.6.0-A4bbz1LO8vMLr2DjySp2jc
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP array-0.5.3.0
    base-4.12.0.0 call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    quickcheck-io-0.2.0-251dhedyI6yFZRutIL9xtc
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz stm-2.5.0.0 time-1.8.0.2
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html: /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-meta-2.6.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-meta
version: 2.6.0
id: hspec-meta-2.6.0-530lixOtQ2Z74tQEk08OLo
key: hspec-meta-2.6.0-530lixOtQ2Z74tQEk08OLo
license: MIT
copyright: (c) 2011-2018 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.
category: Testing
abi: 442d6b14cc9146fc377cef2e83ca9461
exposed: True
exposed-modules:
    Test.Hspec.Meta
hidden-modules: Test.Hspec Test.Hspec.Discover
                Test.Hspec.Formatters Test.Hspec.QuickCheck Test.Hspec.Runner
                Test.Hspec.Core.Clock Test.Hspec.Core.Compat Test.Hspec.Core.Config
                Test.Hspec.Core.Config.Options Test.Hspec.Core.Config.Util
                Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
                Test.Hspec.Core.FailureReport Test.Hspec.Core.Format
                Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
                Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.Hooks
                Test.Hspec.Core.QuickCheck Test.Hspec.Core.QuickCheckUtil
                Test.Hspec.Core.Runner Test.Hspec.Core.Runner.Eval
                Test.Hspec.Core.Spec Test.Hspec.Core.Spec.Monad
                Test.Hspec.Core.Timer Test.Hspec.Core.Tree Test.Hspec.Core.Util
                Control.Concurrent.Async Data.Algorithm.Diff Paths_hspec_meta
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-meta-2.6.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-meta-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-meta-2.6.0
hs-libraries: HShspec-meta-2.6.0-530lixOtQ2Z74tQEk08OLo
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    ansi-terminal-0.8.2-IytGdmUG1lK1dAjqEeG5cq array-0.5.3.0
    base-4.12.0.0 call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    quickcheck-io-0.2.0-251dhedyI6yFZRutIL9xtc
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz stm-2.5.0.0 time-1.8.0.2
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html: /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
